==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Totes les imatges</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No teniu permís per veure la imatge.</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificació</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Mida del fitxer</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Hora d&apos;exposició</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaix</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Obertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llargada focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Obertura màxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesura</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanç de blanc</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensació del flaix</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model de la lent</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espai de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model de la càmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Mida 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajusta a la finestra</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostra la finestra de navegació</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Amaga la finestra de navegació</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Escriviu un nom nou.</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>No teniu permís per veure el fitxer.</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Totes les imatges</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No teniu permís per veure la imatge.</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificació</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Mida del fitxer</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Hora d&apos;exposició</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaix</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Obertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llargada focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Obertura màxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesura</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanç de blanc</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensació del flaix</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model de la lent</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espai de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model de la càmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Mida 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajusta a la finestra</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostra la finestra de navegació</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Amaga la finestra de navegació</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Escriviu un nom nou.</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>No teniu permís per veure el fitxer.</translation>
    </message>
</context>
</TS>
